# BEGIN SourceDeps(oneline):
BuildRequires(pre): rpm-build-python
# END SourceDeps(oneline)
%global soname 0
%global _version 0.3.3

Name:           fife
Epoch:          2
Version:        %{_version}r3
Release:        alt2_5
Summary:        Cross platform game creation framework
Group:          Games/Other
License:        LGPLv2+
URL:            http://www.fifengine.de
# https://sourceforge.net/projects/fife/files/active/src/fife-0.3.3r3.tar.gz/download
# removed ext/   -  removed for using system libs instead of shipped
# removed tests/   -  removed for legal issues
# removed tools/   -  removed for legal issues
# %{name}-dont-build-ext-and-tests.patch - dont build tests/ and ext/. Tools
# should be able to clear out licensing now and introduce a BSD License. We're
# not building it currently. Requires legal validation
Source0:        %{name}_%{version}-clean.tar.gz
Patch99:        %{name}-dont-build-ext-and-tests.patch

BuildRequires:  boost-devel boost-filesystem-devel boost-wave-devel boost-graph-parallel-devel boost-math-devel boost-mpi-devel boost-program_options-devel boost-signals-devel boost-intrusive-devel boost-asio-devel
BuildRequires:  chrpath
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  libguichan-devel
BuildRequires:  libpng-devel
BuildRequires:  libvorbis-devel
BuildRequires:  libXcursor-devel
BuildRequires:  libGLU-devel
BuildRequires:  libopenal-devel
BuildRequires:  python-devel
BuildRequires:  scons
BuildRequires:  libSDL-devel
BuildRequires:  libSDL_ttf-devel
BuildRequires:  libSDL_image-devel
BuildRequires:  swig
BuildRequires:	tinyxml-devel
BuildRequires:  zlib-devel

Requires:	python-module-fife = %{epoch}:%{version}-%{release}
Source44: import.info

%description
FIFE stands for Flexible Isometric Free Engine and is a cross platform
game creation framework. It provides you with the ability to create a
game using Python interfaces.

This package provides the FIFE shared object libraries.

%package  devel
Summary:  FIFE Engine development files
Group:    Development/C
Requires: %{name} = %{epoch}:%{version}-%{release}

%description devel
FIFE stands for Flexible Isometric Free Engine and is a cross platform
game creation framework. It provides you with the ability to create a
game using Python interfaces.

This package provides the development files for FIFE.

%package -n python-module-fife
Summary:        FIFE engine python bindings
Group:          Games/Other

%description -n python-module-fife
FIFE stands for Flexible Isometric Free Engine and is a cross platform
game creation framework. It provides you with the ability to create a
game using Python interfaces.

This package provides the Python game-engine. 

%package doc
Summary:       FIFE Engine bundled documentation
Group:         Documentation
BuildRequires: doxygen
BuildArch:     noarch
Requires:      %{name} = %{epoch}:%{version}-%{release}

%description doc
Doxygen generated documentation for %%{name}. 

%prep
%setup -q -n %{name}_%{version}
%patch99 -p1 -b .clean

# be utf-8 clean, dudes!
for f in ./AUTHORS ./CHANGES ./COPYING ./README
do
 iconv -f iso-8859-1 -t utf-8 $f |sed 's|\r||g' > $f.utf8
 touch -c -r $f $f.utf8
 mv $f.utf8 $f
done 

%build
scons . \
      CXXFLAGS='%{optflags}' \
      --enable-debug \
      --enable-rend-grid \
      --enable-rend-camzone \
      --prefix=%{_prefix} \
      --python-prefix=%{python_sitelibdir} \
      fife-shared fife-python fife-swig

# Doxygen generated docs
doxygen ./doc/doxygen/doxyfile
rm -f ./doc/doxygen/html/installdox


%install

scons . \
      DESTDIR=%{buildroot} \
      CXXFLAGS='%{optflags}' \
      --enable-rend-grid \
      --enable-rend-camzone \
      --enable-debug \
      --prefix=%{_prefix} \
      --lib-dir=%{buildroot}%{_libdir} \
      --python-prefix=%{python_sitelibdir} \
      install-all

# playing a little bit with soname
pushd %{buildroot}%{_libdir}
ln -s lib%{name}.so.%{_version} lib%{name}.so.%{soname}
ln -s lib%{name}.so.%{_version} lib%{name}.so
popd

# rpath is evil, evil, evil
chrpath --delete %{buildroot}%{_libdir}/lib%{name}.so
chrpath --delete %{buildroot}%{python_sitelibdir}/%{name}/_%{name}.so

# dont package static blobs, does anyone really use it?
find %{buildroot}%{_libdir} -type f -name "*.a" -delete -print

mkdir -p %{buildroot}/%{_bindir}/
cat > %{buildroot}/%{_bindir}/%{name}-documentation << EOF
#!/bin/sh
xdg-open file://%{_docdir}/%{name}-doc-%{version}/index.html
EOF
chmod +x %{buildroot}/%{_bindir}/%{name}-documentation

# fife.ppc: E: non-standard-executable-perm /usr/lib/libfife.so.0 0775
chmod 755 %{buildroot}/%{_libdir}/lib%{name}.so.%{soname}
# fife.ppc: E: non-standard-executable-perm /usr/lib/python2.6/site-packages/fife/_fife.so 0775
chmod 755 %{buildroot}/%{python_sitelibdir}/%{name}/_%{name}.so

%files
%doc AUTHORS CHANGES COPYING README
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}.so.%{soname}
%{_libdir}/lib%{name}.so.%{_version}

%files devel
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so

%files doc
%doc ./doc/doxygen/html/*
%{_bindir}/%{name}-documentation

%files -n python-module-fife
%doc AUTHORS CHANGES COPYING README
%{python_sitelibdir}/%{name}/


%changelog
* Mon Feb 11 2013 Igor Vlasenko <viy@altlinux.ru> 2:0.3.3r3-alt2_5
- update to new release by fcimport

* Fri Dec 07 2012 Cronbuild Service <cronbuild@altlinux.org> 2:0.3.3r3-alt2_3
- rebuild to get rid of unmets

* Wed Aug 22 2012 Igor Vlasenko <viy@altlinux.ru> 2:0.3.3r3-alt1_3
- update to new release by fcimport

* Thu Aug 02 2012 Igor Vlasenko <viy@altlinux.ru> 2:0.3.3r3-alt1_2
- update to new release by fcimport

* Tue Jun 12 2012 Igor Vlasenko <viy@altlinux.ru> 2:0.3.3r3-alt1_1
- update to new fc release

